@@ -27,24 +27,26 @@
 #include <QMetaType>
 #include <QString>
 
+
 struct Utf8
 {
-public:
-    Utf8(QChar v);
+  public:
+    Utf8( QChar v );
     Utf8();
 
-public:
+  public:
     QString toString() const;
 
-public:
+  public:
     QChar value;
 };
 
-inline Utf8::Utf8() = default;
-inline Utf8::Utf8(QChar v) : value(v) {}
 
-inline QString Utf8::toString() const { return QString(value); }
+inline Utf8::Utf8() {}
+inline Utf8::Utf8( QChar v ) : value( v ) {}
 
-Q_DECLARE_METATYPE(Utf8)
+inline QString Utf8::toString() const { return QString( value ); }
+
+Q_DECLARE_METATYPE( Utf8 )
 
 #endif
